==> fleet_client-0.8.0.tar.gz: fleet_client-0.8.0/CHANGELOG.md <==
# Changelog

## 0.8.0 (2025-10-23)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/evrimai/fleet-client/compare/v0.7.0...v0.8.0)

### Features

* **api:** api update ([4444dca](https://github.com/evrimai/fleet-client/commit/4444dca72fe6d5b36f225a6b2ad8c4d93c61a26c))
* **api:** api update ([f1e71cf](https://github.com/evrimai/fleet-client/commit/f1e71cf3ced33fbd321e3a5b37b405df99e762bd))

## 0.7.0 (2025-10-22)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/evrimai/fleet-client/compare/v0.6.0...v0.7.0)

### Features

* **api:** api update ([be01898](https://github.com/evrimai/fleet-client/commit/be01898710be8527d4bafbd3913a89d0c75814d9))

## 0.6.0 (2025-10-21)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/evrimai/fleet-client/compare/v0.5.0...v0.6.0)

### Features

* **api:** api update ([12e90ed](https://github.com/evrimai/fleet-client/commit/12e90edb57ac90c955b17ae65d024d93553283eb))
* **api:** api update ([79508da](https://github.com/evrimai/fleet-client/commit/79508da7d93a2b38aeb0dcef31cf721dc2be7c15))
* **api:** api update ([af8cacc](https://github.com/evrimai/fleet-client/commit/af8cacc836e4246dbf46229052dd166e2a79e386))
* **api:** manual updates ([44ee318](https://github.com/evrimai/fleet-client/commit/44ee3182469fbcda1ff23de5a707c09e9c921a8c))

## 0.5.0 (2025-10-21)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/evrimai/fleet-client/compare/v0.4.0...v0.5.0)

### Features

* **api:** api update ([d412590](https://github.com/evrimai/fleet-client/commit/d41259033e4019c8b0bbae82a3777f61168ac613))
* **api:** manual updates ([64be9c1](https://github.com/evrimai/fleet-client/commit/64be9c1ce4656d6b8642a0c7c2ebfd7e18c00084))

## 0.4.0 (2025-10-21)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/evrimai/fleet-client/compare/v0.3.0...v0.4.0)

### Features

* **api:** manual updates for owners ([eeb3e46](https://github.com/evrimai/fleet-client/commit/eeb3e46ceb951a44241af103613b8af6dd7f4fb8))

## 0.3.0 (2025-10-21)

Full Changelog: [v0.2.2...v0.3.0](https://github.com/evrimai/fleet-client/compare/v0.2.2...v0.3.0)

### Features

* **api:** api update ([38a7416](https://github.com/evrimai/fleet-client/commit/38a7416cf6ddd58aa1e7adb90b1d4eb704ff463f))
* **api:** api update ([dce1369](https://github.com/evrimai/fleet-client/commit/dce13692486dfd073ad58ade34d2888a6590660b))

## 0.2.2 (2025-10-18)

Full Changelog: [v0.2.1...v0.2.2](https://github.com/evrimai/fleet-client/compare/v0.2.1...v0.2.2)

### Chores

* sync repo ([29846d9](https://github.com/evrimai/fleet-client/commit/29846d9a1daeafb06856842be735ce3d2431445d))
* update SDK settings ([c115c3e](https://github.com/evrimai/fleet-client/commit/c115c3e4a83059d7df3cf24a79e410a7bbd20b36))
* update SDK settings ([1d925fe](https://github.com/evrimai/fleet-client/commit/1d925fe2b09a44b1264df8fc468a45abdf486d11))

## 0.2.1 (2025-10-18)

Full Changelog: [v0.2.0...v0.2.1](https://github.com/evrimai/fleet-client/compare/v0.2.0...v0.2.1)

### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([0f95f44](https://github.com/evrimai/fleet-client/commit/0f95f449a11fe83f6eafd99b93436d7ee58de168))

## 0.2.0 (2025-10-11)

Full Changelog: [v0.1.1...v0.2.0](https://github.com/evrimai/fleet-client/compare/v0.1.1...v0.2.0)

### Features

* improve future compat with pydantic v3 ([c8691f1](https://github.com/evrimai/fleet-client/commit/c8691f125561c469a298672d1e367111f7198bb3))
* **types:** replace List[str] with SequenceNotStr in params ([8f32157](https://github.com/evrimai/fleet-client/commit/8f3215724d47844374b296b5ba086c7947157cd0))


### Bug Fixes

* avoid newer type syntax ([2a164e8](https://github.com/evrimai/fleet-client/commit/2a164e875d4cd861b984e3615a78aac98b9265bd))


### Chores

* do not install brew dependencies in ./scripts/bootstrap by default ([f36a4cd](https://github.com/evrimai/fleet-client/commit/f36a4cd011f4a2918a8df46043ce06c0b09c2be5))
* **internal:** add Sequence related utils ([cd3e713](https://github.com/evrimai/fleet-client/commit/cd3e713c5830f3a836eedb2b975e22003d3f769c))
* **internal:** change ci workflow machines ([0df0fba](https://github.com/evrimai/fleet-client/commit/0df0fba25bab2a88dfdd10712882a3daf09a7be6))
* **internal:** detect missing future annotations with ruff ([929726d](https://github.com/evrimai/fleet-client/commit/929726daea0669365219252fe951eb45070274a1))
* **internal:** move mypy configurations to `pyproject.toml` file ([8d878bf](https://github.com/evrimai/fleet-client/commit/8d878bf66b804f2363d81cf11b8776cea71c3013))
* **internal:** update pydantic dependency ([15e929f](https://github.com/evrimai/fleet-client/commit/15e929fb7cb27e7d15c4482b12267d18092eebe6))
* **internal:** update pyright exclude list ([e3e3610](https://github.com/evrimai/fleet-client/commit/e3e36109bc89d95d2feca7f8d57c4b44a4b64cfa))
* **tests:** simplify `get_platform` test ([304818a](https://github.com/evrimai/fleet-client/commit/304818a66dc6b87b9d0dbf8962b1b0f74910f0ce))
* **types:** change optional parameter type from NotGiven to Omit ([e8fda68](https://github.com/evrimai/fleet-client/commit/e8fda68010aabfe3439560b04fae38537e7668fd))

## 0.1.1 (2025-08-22)

Full Changelog: [v0.1.0...v0.1.1](https://github.com/evrimai/fleet-client/compare/v0.1.0...v0.1.1)

### Chores

* update github action ([c381e7b](https://github.com/evrimai/fleet-client/commit/c381e7bf6e43d386fba8b6a0b97c640fc546252d))

## 0.1.0 (2025-08-12)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/evrimai/fleet-client/compare/v0.0.1...v0.1.0)

### Chores

* update SDK settings ([cdf80fa](https://github.com/evrimai/fleet-client/commit/cdf80fa800399b84a4be3220a6700d29f6e63acf))
* update SDK settings ([7eb1ac3](https://github.com/evrimai/fleet-client/commit/7eb1ac32ce6ee54bffea2c5fdb51d7fdd3d760f1))

==> fleet_client-0.10.0.tar.gz: fleet_client-0.10.0/CHANGELOG.md <==
# Changelog

## 0.10.0 (2025-11-02)

Full Changelog: [v0.9.0...v0.10.0](https://github.com/evrimai/fleet-client/compare/v0.9.0...v0.10.0)

### Features

* **api:** api update ([284b65f](https://github.com/evrimai/fleet-client/commit/284b65f9b3d621a46550b4f1903b76425e4d70e3))
* **api:** api update ([fbe9698](https://github.com/evrimai/fleet-client/commit/fbe96981657c96c3b0c2d17b5ac2c8dd3356866c))
* **api:** manual updates ([97ddb81](https://github.com/evrimai/fleet-client/commit/97ddb8184e4575548fce8484c2b30143e6c3b85b))


### Chores

* **internal/tests:** avoid race condition with implicit client cleanup ([1e9b188](https://github.com/evrimai/fleet-client/commit/1e9b1887c9e824ea2eed742fef0137a049862a74))

## 0.9.0 (2025-10-31)

Full Changelog: [v0.8.0...v0.9.0](https://github.com/evrimai/fleet-client/compare/v0.8.0...v0.9.0)

### Features

* **api:** api update ([51584d2](https://github.com/evrimai/fleet-client/commit/51584d2fd754afcddcf6655ff67bc761fea45a51))
* **api:** manual updates ([375ffb9](https://github.com/evrimai/fleet-client/commit/375ffb99c18461572a4aebf1eb26028cb786672f))


### Bug Fixes

* **client:** close streams without requiring full consumption ([ddfceb0](https://github.com/evrimai/fleet-client/commit/ddfceb02c2d1bd42a7444c59ed42f8b28c9c70c7))

## 0.8.0 (2025-10-23)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/evrimai/fleet-client/compare/v0.7.0...v0.8.0)

### Features

* **api:** api update ([4444dca](https://github.com/evrimai/fleet-client/commit/4444dca72fe6d5b36f225a6b2ad8c4d93c61a26c))
* **api:** api update ([f1e71cf](https://github.com/evrimai/fleet-client/commit/f1e71cf3ced33fbd321e3a5b37b405df99e762bd))

## 0.7.0 (2025-10-22)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/evrimai/fleet-client/compare/v0.6.0...v0.7.0)

### Features

* **api:** api update ([be01898](https://github.com/evrimai/fleet-client/commit/be01898710be8527d4bafbd3913a89d0c75814d9))

## 0.6.0 (2025-10-21)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/evrimai/fleet-client/compare/v0.5.0...v0.6.0)

### Features

* **api:** api update ([12e90ed](https://github.com/evrimai/fleet-client/commit/12e90edb57ac90c955b17ae65d024d93553283eb))
* **api:** api update ([79508da](https://github.com/evrimai/fleet-client/commit/79508da7d93a2b38aeb0dcef31cf721dc2be7c15))
* **api:** api update ([af8cacc](https://github.com/evrimai/fleet-client/commit/af8cacc836e4246dbf46229052dd166e2a79e386))
* **api:** manual updates ([44ee318](https://github.com/evrimai/fleet-client/commit/44ee3182469fbcda1ff23de5a707c09e9c921a8c))

## 0.5.0 (2025-10-21)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/evrimai/fleet-client/compare/v0.4.0...v0.5.0)

### Features

* **api:** api update ([d412590](https://github.com/evrimai/fleet-client/commit/d41259033e4019c8b0bbae82a3777f61168ac613))
* **api:** manual updates ([64be9c1](https://github.com/evrimai/fleet-client/commit/64be9c1ce4656d6b8642a0c7c2ebfd7e18c00084))

## 0.4.0 (2025-10-21)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/evrimai/fleet-client/compare/v0.3.0...v0.4.0)

### Features

* **api:** manual updates for owners ([eeb3e46](https://github.com/evrimai/fleet-client/commit/eeb3e46ceb951a44241af103613b8af6dd7f4fb8))

## 0.3.0 (2025-10-21)

Full Changelog: [v0.2.2...v0.3.0](https://github.com/evrimai/fleet-client/compare/v0.2.2...v0.3.0)

### Features

* **api:** api update ([38a7416](https://github.com/evrimai/fleet-client/commit/38a7416cf6ddd58aa1e7adb90b1d4eb704ff463f))
* **api:** api update ([dce1369](https://github.com/evrimai/fleet-client/commit/dce13692486dfd073ad58ade34d2888a6590660b))

## 0.2.2 (2025-10-18)

Full Changelog: [v0.2.1...v0.2.2](https://github.com/evrimai/fleet-client/compare/v0.2.1...v0.2.2)

### Chores

* sync repo ([29846d9](https://github.com/evrimai/fleet-client/commit/29846d9a1daeafb06856842be735ce3d2431445d))
* update SDK settings ([c115c3e](https://github.com/evrimai/fleet-client/commit/c115c3e4a83059d7df3cf24a79e410a7bbd20b36))
* update SDK settings ([1d925fe](https://github.com/evrimai/fleet-client/commit/1d925fe2b09a44b1264df8fc468a45abdf486d11))

## 0.2.1 (2025-10-18)

Full Changelog: [v0.2.0...v0.2.1](https://github.com/evrimai/fleet-client/compare/v0.2.0...v0.2.1)

### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([0f95f44](https://github.com/evrimai/fleet-client/commit/0f95f449a11fe83f6eafd99b93436d7ee58de168))

## 0.2.0 (2025-10-11)

Full Changelog: [v0.1.1...v0.2.0](https://github.com/evrimai/fleet-client/compare/v0.1.1...v0.2.0)

### Features

* improve future compat with pydantic v3 ([c8691f1](https://github.com/evrimai/fleet-client/commit/c8691f125561c469a298672d1e367111f7198bb3))
* **types:** replace List[str] with SequenceNotStr in params ([8f32157](https://github.com/evrimai/fleet-client/commit/8f3215724d47844374b296b5ba086c7947157cd0))


### Bug Fixes

* avoid newer type syntax ([2a164e8](https://github.com/evrimai/fleet-client/commit/2a164e875d4cd861b984e3615a78aac98b9265bd))


### Chores

* do not install brew dependencies in ./scripts/bootstrap by default ([f36a4cd](https://github.com/evrimai/fleet-client/commit/f36a4cd011f4a2918a8df46043ce06c0b09c2be5))
* **internal:** add Sequence related utils ([cd3e713](https://github.com/evrimai/fleet-client/commit/cd3e713c5830f3a836eedb2b975e22003d3f769c))
* **internal:** change ci workflow machines ([0df0fba](https://github.com/evrimai/fleet-client/commit/0df0fba25bab2a88dfdd10712882a3daf09a7be6))
* **internal:** detect missing future annotations with ruff ([929726d](https://github.com/evrimai/fleet-client/commit/929726daea0669365219252fe951eb45070274a1))
* **internal:** move mypy configurations to `pyproject.toml` file ([8d878bf](https://github.com/evrimai/fleet-client/commit/8d878bf66b804f2363d81cf11b8776cea71c3013))
* **internal:** update pydantic dependency ([15e929f](https://github.com/evrimai/fleet-client/commit/15e929fb7cb27e7d15c4482b12267d18092eebe6))
* **internal:** update pyright exclude list ([e3e3610](https://github.com/evrimai/fleet-client/commit/e3e36109bc89d95d2feca7f8d57c4b44a4b64cfa))
* **tests:** simplify `get_platform` test ([304818a](https://github.com/evrimai/fleet-client/commit/304818a66dc6b87b9d0dbf8962b1b0f74910f0ce))
* **types:** change optional parameter type from NotGiven to Omit ([e8fda68](https://github.com/evrimai/fleet-client/commit/e8fda68010aabfe3439560b04fae38537e7668fd))

## 0.1.1 (2025-08-22)

Full Changelog: [v0.1.0...v0.1.1](https://github.com/evrimai/fleet-client/compare/v0.1.0...v0.1.1)

### Chores

* update github action ([c381e7b](https://github.com/evrimai/fleet-client/commit/c381e7bf6e43d386fba8b6a0b97c640fc546252d))

## 0.1.0 (2025-08-12)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/evrimai/fleet-client/compare/v0.0.1...v0.1.0)

### Chores

* update SDK settings ([cdf80fa](https://github.com/evrimai/fleet-client/commit/cdf80fa800399b84a4be3220a6700d29f6e63acf))
* update SDK settings ([7eb1ac3](https://github.com/evrimai/fleet-client/commit/7eb1ac32ce6ee54bffea2c5fdb51d7fdd3d760f1))
